<p align="center">
    <br>
    <b>coloriran Library for Python</b>
    <br>
</p>

## coloriran

``` python
from coloriran import Fore

print(Fore.GREEN, "Hello!")
print(Fore.RED, "Hello!")
print(Fore.WHITE, "Hello!")
print(Fore.BLUE, "Hello!")
```

### Installing

``` bash
pip3 install TyroBot
```


© 2023 Mohammad Saeed Salari